@@ -179,7 +179,7 @@ fn thermal_power_features() {
         eax: ThermalPowerFeaturesEax { bits: 119 },
         ebx: 2,
         ecx: ThermalPowerFeaturesEcx { bits: 9 },
-        edx: 0,
+        _edx: 0,
     };
 
     assert!(tpfeatures.eax.contains(ThermalPowerFeaturesEax::DTS));
@@ -213,7 +213,7 @@ fn thermal_power_features() {
             | ThermalPowerFeaturesEax::HDC,
         ebx: 2,
         ecx: ThermalPowerFeaturesEcx::HW_COORD_FEEDBACK | ThermalPowerFeaturesEcx::ENERGY_BIAS_PREF,
-        edx: 0,
+        _edx: 0,
     };
 
     assert!(tpfeatures.has_dts());
@@ -237,12 +237,12 @@ fn thermal_power_features() {
 #[test]
 fn extended_features() {
     let tpfeatures = ExtendedFeatures {
-        eax: 0,
+        _eax: 0,
         ebx: ExtendedFeaturesEbx { bits: 641 },
         ecx: ExtendedFeaturesEcx { bits: 0 },
-        edx: 0,
+        _edx: 0,
     };
-    assert!(tpfeatures.eax == 0);
+    assert!(tpfeatures._eax == 0);
     assert!(tpfeatures.has_fsgsbase());
     assert!(!tpfeatures.has_tsc_adjust_msr());
     assert!(!tpfeatures.has_bmi1());
@@ -257,7 +257,7 @@ fn extended_features() {
     assert!(!tpfeatures.has_fpu_cs_ds_deprecated());
 
     let tpfeatures2 = ExtendedFeatures {
-        eax: 0,
+        _eax: 0,
         ebx: ExtendedFeaturesEbx::FSGSBASE
             | ExtendedFeaturesEbx::ADJUST_MSR
             | ExtendedFeaturesEbx::BMI1
@@ -274,7 +274,7 @@ fn extended_features() {
             | ExtendedFeaturesEbx::CLFLUSHOPT
             | ExtendedFeaturesEbx::PROCESSOR_TRACE,
         ecx: ExtendedFeaturesEcx { bits: 0 },
-        edx: 201326592,
+        _edx: 201326592,
     };
 
     assert!(tpfeatures2.has_fsgsbase());
@@ -305,7 +305,7 @@ fn performance_monitoring_info() {
     let pm = PerformanceMonitoringInfo {
         eax: 120587267,
         ebx: PerformanceMonitoringFeaturesEbx { bits: 0 },
-        ecx: 0,
+        _ecx: 0,
         edx: 1539,
     };
 
@@ -375,11 +375,11 @@ fn extended_state_info() {
         eax: ExtendedStateInfoXCR0Flags { bits: 7 },
         ebx: 832,
         ecx: 832,
-        edx: 0,
+        _edx: 0,
         eax1: 1,
         ebx1: 0,
         ecx1: ExtendedStateInfoXSSFlags { bits: 0 },
-        edx1: 0,
+        _edx1: 0,
     };
 
     assert!(es.xsave_area_size_enabled_features() == 832);
@@ -410,11 +410,11 @@ fn extended_state_info3() {
             | ExtendedStateInfoXCR0Flags::PKRU,
         ebx: 2688,
         ecx: 2696,
-        edx: 0,
+        _edx: 0,
         eax1: 15,
         ebx1: 2560,
         ecx1: ExtendedStateInfoXSSFlags::PT,
-        edx1: 0,
+        _edx1: 0,
     };
 
     assert!(esi.xcr0_supports_legacy_x87());
@@ -561,11 +561,11 @@ fn extended_state_info2() {
         eax: ExtendedStateInfoXCR0Flags { bits: 31 },
         ebx: 1088,
         ecx: 1088,
-        edx: 0,
+        _edx: 0,
         eax1: 15,
         ebx1: 960,
         ecx1: ExtendedStateInfoXSSFlags { bits: 256 },
-        edx1: 0,
+        _edx1: 0,
     };
 
     assert!(es.xcr0_supports_legacy_x87());
@@ -732,7 +732,7 @@ fn sgx_test() {
         read: Default::default(),
         eax: 1,
         ebx: 0,
-        ecx: 0,
+        _ecx: 0,
         edx: 9247,
         eax1: 54,
         ebx1: 0,
@@ -747,90 +747,3 @@ fn sgx_test() {
     assert!(sgx.miscselect() == 0x0);
     assert!(sgx.secs_attributes() == (0x0000000000000036, 0x000000000000001f));
 }
-
-#[cfg(test)]
-#[test]
-fn readme_test() {
-    // let cpuid = CpuId::new();
-    //
-    // match cpuid.get_vendor_info() {
-    // Some(vf) => assert!(vf.as_string() == "GenuineIntel"),
-    // None => ()
-    // }
-    //
-    // let has_sse = match cpuid.get_feature_info() {
-    // Some(finfo) => finfo.has_sse(),
-    // None => false
-    // };
-    //
-    // if has_sse {
-    // println!("CPU supports SSE!");
-    // }
-    //
-    // match cpuid.get_cache_parameters() {
-    // Some(cparams) => {
-    // for cache in cparams {
-    // let size = cache.associativity() * cache.physical_line_partitions() * cache.coherency_line_size() * cache.sets();
-    // println!("L{}-Cache size is {}", cache.level(), size);
-    // }
-    // },
-    // None => println!("No cache parameter information available"),
-    // }
-    //
-}
-
-/*
-extern crate serde_json;
-
-#[cfg(test)]
-#[test]
-fn test_serializability() {
-    #[derive(Debug, Default, Serialize, Deserialize)]
-    struct SerializeDeserializeTest {
-        _x1: CpuId,
-        _x2: CpuIdResult,
-        _x3: VendorInfo,
-        _x4: CacheInfoIter,
-        _x5: CacheInfo,
-        _x6: ProcessorSerial,
-        _x7: FeatureInfo,
-        _x8: CacheParametersIter,
-        _x9: CacheParameter,
-        _x10: MonitorMwaitInfo,
-        _x11: ThermalPowerInfo,
-        _x12: ExtendedFeatures,
-        _x13: DirectCacheAccessInfo,
-        _x14: PerformanceMonitoringInfo,
-        _x15: ExtendedTopologyIter,
-        _x16: ExtendedTopologyLevel,
-        _x17: ExtendedStateInfo,
-        _x18: ExtendedStateIter,
-        _x19: ExtendedState,
-        _x20: RdtAllocationInfo,
-        _x21: RdtMonitoringInfo,
-        _x22: L3CatInfo,
-        _x23: L2CatInfo,
-        _x24: ProcessorTraceInfo,
-        _x25: ProcessorTraceIter,
-        _x26: ProcessorTrace,
-        _x27: TscInfo,
-        _x28: ProcessorFrequencyInfo,
-        _x29: SoCVendorInfo,
-        _x30: SoCVendorAttributesIter,
-        _x31: SoCVendorBrand,
-        _x32: ExtendedFunctionInfo,
-        _x33: MemBwAllocationInfo,
-        _x34: L3MonitoringInfo,
-        _x35: SgxSectionInfo,
-        _x36: EpcSection,
-        _x37: SgxInfo,
-        _x38: SgxSectionIter,
-        _x39: DatInfo,
-        _x40: DatIter,
-        _x41: DatType,
-    }
-
-    let st: SerializeDeserializeTest = Default::default();
-    let test = serde_json::to_string(&st).unwrap();
-    let _st: SerializeDeserializeTest = serde_json::from_str(&test).unwrap();
-}*/
